library(lme4)

setwd("~/Data_AnalysisCode")
UndDataAdults <- read.table("Adult_und.txt", header=T)
summary(UndDataAdults)
## explanation of headers
## Item: Item ID
## lfdNr: presentation order
## pict1: noun presented in lower left quadrant
## pict2: noun presented in upper right quadrant
## item1: features of noun in lower left: "bj"=animate, iambic; "bt"=animate, trochaic; "uj"=inanimate, iambic; "ut"=inanimate, trochaic
## item2: features of noun in upper right: "bj"=animate, iambic; "bt"=animate, trochaic; "uj"=inanimate, iambic; "ut"=inanimate, trochaic
## Freq_1: corpus frequency for item presented in lower left (per million words)
## Freq_2: corpus frequency for item presented in upper right (per million words)
## Freq_1_log: log of Freq_1
## Freq_2_log: log of Freq_2
## Freq_Diff_log: Freq_2_log-Freq_1_log
## Belebtheit: -1 if pict1 is animate AND pict2 is inanimate; 1 if pict1 is inanimate AND pict2 is animate; 0 otherwise
## Rhythmus: -1 if pict1 is iambic AND pict2 is trochaic; 1 if pict1 is trochaic AND pict2 is iambic; 0 otherwise
## liste: list participant was assigned to
## variable: Participant ID 
## value: chosen order; 0=lower left first; 1=upper right first
## FreqReal: -1 if lower frequency item was named first; 1 if higher frequency item was named first
## Item1Bel: "belebt" if pict1 is animate; "unbelebt" if pict1 is inanimate
## Item2Bel: "belebt" if pict2 is animate; "unbelebt" if pict2 is inanimate
## Item1Rhy: "iamb" if pict1 is iambic; "troch" if pict1 is trochaic
## Item2Bel: "iamb" if pict1 is iambic; "troch" if pict1 is trochaic
## vary: "exclude" marks participants that only chose one spacial order; "var" marks participants that change order at least once
## RhythmReal: 1: chosen order yields "rhythmic" result, i.e. iamb>trochee; -1: chosen order yields disrhythmic result, i.e. trochee>iamb; 0 otherwise
## BelebtReal: 1: chosen order observes animacy constraint, i.e. animate>inanimate; -1: chosen order violates animacy constraint, i.e. inanimate>animate; 0 otherwise
## ANIM: -.5 if pict1 is animate AND pict2 is inanimate; .5 if pict1 is inanimate AND pict2 is animate; 0 otherwise
## LAPSE: -.5 if pict1 is iambic AND pict2 is trochaic; .5 if pict1 is trochaic AND pict2 is iambic; 0 otherwise


## Add columns for uniformity/difference between the pictures of each item pair concerning animacy and rhythm (coded as orthogonal sum contrasts)
UndDataAdults$ANIM_Diff <- with(UndDataAdults, ifelse(ANIM==0,-.5,.5))
UndDataAdults$LAPSE_Diff <- with(UndDataAdults, ifelse(LAPSE==0,-.5,.5))


## exclude participants that always use only one spacial order (dependent variable does not vary)
UndDataClean<-UndDataAdults[UndDataAdults$vary!="exclude",]

summary(UndDataClean)

dim(UndDataClean)



########### PLOT ################

E_SpacialOrder <- with(UndDataClean, tapply(value, variable, mean)) ## upper right > lower left
D_Frequency <- with(UndDataClean, tapply((FreqReal+1)/2, variable, mean)) ## lower frequent > higher frequent item
C_Animacy <- with(UndDataClean[UndDataClean$ANIM!=0,], tapply((BelebtReal+1)/2, variable, mean)) ## animate referent > inanimate
B_RhythmAll <- with(UndDataClean[UndDataClean$LAPSE!=0,], tapply((RhythmReal+1)/2, variable, mean)) ## trochee > iamb
A_RhythmAnim0 <- with(UndDataClean[UndDataClean$ANIM==0,], tapply((RhythmReal+1)/2, variable, mean)) ## trochee > iamb


PlotAdultData <- list(A_RhythmAnim0, B_RhythmAll,C_Animacy, D_Frequency,E_SpacialOrder)

## plot results (means per participant)
par(mar=c(5.1,8.1,4.1,8.1))
boxplot(PlotAdultData, horizontal=T, range=0,ylim=c(0,1), yaxt="n", boxwex=.4, whisklty=1)
stripchart(PlotAdultData, method="jitter", pch=21, col="darkgrey", add=T)
abline(v=0.5, lty=2, col="grey")
abline(h=1.7, lty=1)
axis(side=2, at=c(1:5), labels=c("trochee","trochee","inanimate","lower","lower left"), las=2, cex.axis=.9)
axis(side=4, at=c(1:5), labels=c("iamb","iamb","animate","higher","upper right"), las=2, cex.axis=.9)
text(x=0.5, y=c(1:5)+.35, labels=c("rhythm (subset: animacy invariant)",
                                   "rhythm", "animacy", "word frequency", "position"), bg=1, cex=1)





# regression models
# specifying random slopes leads to convergence problems

#full model 

modelFull<-glmer(value~LAPSE*ANIM+LAPSE*ANIM_Diff+Freq_Diff_log+(1|variable)+(1|Item), family=binomial, data=UndDataClean)
summary(modelFull)

#model for subset (ANIM=0)

modelSubset<-glmer(value~LAPSE+Freq_Diff_log+(1|variable)+(1|Item), family=binomial, data=UndDataClean[UndDataClean$ANIM==0,])
summary(modelSubset)


