library(lme4)
library(ggpubr)


setwd("~/Data_AnalysisCode")
### load data table
UndKids <- read.table("Child_und.txt", header=T)
summary(UndKids)
dim(UndKids)
## explanation of headers
## Item: Item ID
## lfdNr: presentation order
## pict1: noun presented in lower left
## pict2: noun presented in upper right
## item1: features of noun in lower left: "bj"=animate, iambic; "bt"=animate, trochaic; "uj"=inanimate, iambic; "ut"=inanimate, trochaic
## item2: features of noun in upper right: "bj"=animate, iambic; "bt"=animate, trochaic; "uj"=inanimate, iambic; "ut"=inanimate, trochaic
## Freq_1: corpus frequency for item presented in lower left (per million words)
## Freq_2: corpus frequency for item presented in upper right (per million words)
## Freq_1_log: log of Freq_1
## Freq_2_log: log of Freq_2
## Freq_Diff_log: Freq_2_log-Freq_1_log
## Belebtheit: -1 if pict1 is animate AND pict2 is inanimate; 1 if pict1 is inanimate AND pict2 is animate; 0 otherwise
## Rhythmus: -1 if pict1 is iambic AND pict2 is trochaic; 1 if pict1 is trochaic AND pict2 is iambic; 0 otherwise
## liste: list participant was assigned to
## variable: Participant ID 
## AgeMonths: Age of partipant (in months)
## CenterAge: Age centered to mean age (64.444 months), rescaled to year, i.e. divided by 12
## value: chosen order; 0=lower left first; 1=upper right first
## FreqReal: -1 if lower frequency item was named first; 1 if higher frequency item was named first
## Item1Bel: "belebt" if pict1 is animate; "unbelebt" if pict1 is inanimate
## Item2Bel: "belebt" if pict2 is animate; "unbelebt" if pict2 is inanimate
## Item1Rhy: "iamb" if pict1 is iambic; "troch" if pict1 is trochaic
## Item2Bel: "iamb" if pict1 is iambic; "troch" if pict1 is trochaic
## vary: "exclude" marks participants that only chose one spacial order; "var" marks participants that change order at least once
## RhythmReal: 1: chosen order yields "rhythmic" result, i.e. iamb>trochee; -1: chosen order yields disrhythmic result, i.e. trochee>iamb; 0 otherwise
## BelebtReal: 1: chosen order observes animacy constraint, i.e. animate>inanimate; -1: chosen order violates animacy constraint, i.e. inanimate>animate; 0 otherwise
## ANIM: -.5 if pict1 is animate AND pict2 is inanimate; .5 if pict1 is inanimate AND pict2 is animate; 0 otherwise
## RHY: -.5 if pict1 is iambic AND pict2 is trochaic; .5 if pict1 is trochaic AND pict2 is iambic; 0 otherwise

## Add columns for uniformity/difference between the pictures of each item pair concerning animacy and rhythm (coded as orthogonal sum contrasts)
UndKids$ANIM_Diff <- with(UndKids, ifelse(ANIM==0,-.5,.5))
UndKids$LAPSE_Diff <- with(UndKids, ifelse(RHY==0,-.5,.5))


## exclude participants that always use only one spacial order (dependent variable does not vary)
UndKidsClean<-UndKids[UndKids$vary!="exclude",] # no exclusions in this experiment

summary(UndKidsClean)

dim(UndKidsClean)


########### PLOT ################

E_SpacialOrder <- with(UndKidsClean, tapply(value, variable, mean)) ## upper right > lower left
D_Frequency <- with(UndKidsClean, tapply((FreqReal+1)/2, variable, mean)) ## lower frequent > higher frequent item
C_Animacy <- with(UndKidsClean[UndKidsClean$ANIM!=0,], tapply((BelebtReal+1)/2, variable, mean)) ## animate referent > inanimate
B_RhythmAll <- with(UndKidsClean[UndKidsClean$RHY!=0,], tapply((RhythmReal+1)/2, variable, mean)) ## trochee > iamb
A_RhythmAnim0 <- with(UndKidsClean[UndKidsClean$ANIM==0,], tapply((RhythmReal+1)/2, variable, mean)) ## trochee > iamb


PlotKidsData <- list(A_RhythmAnim0, B_RhythmAll,C_Animacy, D_Frequency,E_SpacialOrder)

## plot results (means per participant)
par(mar=c(5.1,8.1,4.1,8.1))
boxplot(PlotKidsData, horizontal=T, range=0,ylim=c(0,1), yaxt="n", boxwex=.4, whisklty=1)
stripchart(PlotKidsData, method="jitter", pch=21, col="darkgrey", add=T)
abline(v=0.5, lty=2, col="grey")
abline(h=1.7, lty=1)
axis(side=2, at=c(1:5), labels=c("trochee","trochee","inanimate","lower","lower left"), las=2, cex.axis=.9)
axis(side=4, at=c(1:5), labels=c("iamb","iamb","animate","higher","upper right"), las=2, cex.axis=.9)
text(x=0.5, y=c(1:5)+.35, labels=c("rhythm (subset: animacy invariant)",
                                   "rhythm", "animacy", "word frequency", "position"), bg=1, cex=1)




# regression models
# specifying random slopes leads to convergence problems

#full model 
modelFull<-glmer(value~ANIM*RHY+
                   ANIM*CenterAge+RHY*CenterAge+ANIM_Diff*RHY+Freq_Diff_log+(1|variable)+(1|Item), family=binomial, data=UndKidsClean)

summary(modelFull)


## model of data subset (stimulus pictures do not vary w.r.t. animacy, ANIM==0)
modelSubset<-glmer(value~RHY+
                   RHY*CenterAge+Freq_Diff_log+(1|variable)+(1|Item), family=binomial, data=UndKidsClean[UndKidsClean$ANIM==0,])
                                                                                                         

summary(modelSubset)


# Aggrregated data per participant for scatterplots (for correlations of age with other factors of interest)

AgeTabs <- read.csv("AgeTabs.csv", header=T)

summary(AgeTabs)
## explanation of headers
## AgeMonths: Age in number of months
## ParticipantID: Participant identifier
## nResponses: number of valid responses per participant
## ANIM1Ratio: ratio of responses that adhere to the ANIM constraint
## IAMB1Ratio: ratio of responses that adhere to the *CLASH constraint
## StandardSeq: ratio of responses with standard sequence A>B


Pos_AgePlot<- ggscatter(AgeTabs, 
                        y = "StandardSeq", x = "AgeMonths", 
                        add = "reg.line", conf.int = TRUE, add.params = list(color = "blue", fill = "lightgray"),
                        cor.coef = TRUE, cor.method = "pearson",
                        ylab = "Proportion A > B", xlab = "Age in Months")+
  geom_hline(yintercept=.5, linetype="dashed", color = "red")


ggpar(Pos_AgePlot, ylim=c(0,.8), title="Adherence to standard sequence by age")


ANIM_AgePlot<- ggscatter(AgeTabs, 
                         y = "ANIM1Ratio", x = "AgeMonths", 
                         add = "reg.line", conf.int = TRUE, add.params = list(color = "blue", fill = "lightgray"),
                         cor.coef = TRUE, cor.method = "pearson",
                         ylab = "Proportion animate first responses", xlab = "Age in Months")+
  geom_hline(yintercept=.5, linetype="dashed", color = "red")


ggpar(ANIM_AgePlot, ylim=c(0.2,1), title="Adherence to ANIM constraint by age")


CLASH_AgePlot<- ggscatter(AgeTabs, 
                          y = "IAMB1Ratio", x = "AgeMonths", 
                          add = "reg.line", conf.int = TRUE, add.params = list(color = "blue", fill = "lightgray"),
                          cor.coef = TRUE, cor.method = "pearson",
                          ylab = "Proportion iamb first responses", xlab = "Age in Months")+
  geom_hline(yintercept=.5, linetype="dashed", color = "red")


ggpar(CLASH_AgePlot, ylim=c(0.1,.8), title="Adherence to *CLASH constraint by age")



